@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,6 +22,9 @@ public:
     explicit MessageFactoryTest(QObject *parent = nullptr);
     ~MessageFactoryTest() override;
 
+public:
+    static void initMain();
+
 private Q_SLOTS:
     void initTestCase();
     void init();
@@ -50,11 +53,13 @@ private Q_SLOTS:
     void testCreateReplyToAllWithUseSenderByNoSameIdentitiesAsync();
     void testCreateReplyToAllWithUseSenderAndIdentityInCCAsync();
 
+    void testCreateReplyWithForcedCharset();
+
     void cleanupTestCase();
 
 private:
     Q_REQUIRED_RESULT KMime::Message::Ptr createPlainTestMessage();
     Q_REQUIRED_RESULT KMime::Message::Ptr createPlainTestMessageWithMultiEmails();
+    Q_REQUIRED_RESULT KMime::Message::Ptr createReplyAllForMessage(KMime::Message::Ptr origMsg);
     KIdentityManagement::IdentityManager *mIdentMan = nullptr;
 };
-
