@@ -11,12 +11,10 @@
 #include "core/delegate.h"
 #include "core/groupheaderitem.h"
 #include "core/item.h"
-#include "core/manager.h"
 #include "core/messageitem.h"
 #include "core/model.h"
 #include "core/storagemodelbase.h"
 #include "core/theme.h"
-#include "core/twofingertap.h"
 #include "core/widgetbase.h"
 #include "messagelistsettings.h"
 #include "messagelistutil.h"
@@ -24,9 +22,10 @@
 
 #include "MessageCore/StringUtil"
 
-#include <kmime/kmime_dateformatter.h> // kdepimlibs
+#include <KMime/DateFormatter> // kdepimlibs
 
-#include <Item>
+#include <Akonadi/Item>
+#include <KTwoFingerTap>
 #include <QApplication>
 #include <QGestureEvent>
 #include <QHeaderView>
@@ -44,10 +43,10 @@
 
 using namespace MessageList::Core;
 
-class Q_DECL_HIDDEN View::Private
+class View::ViewPrivate
 {
 public:
-    Private(View *owner, Widget *parent)
+    ViewPrivate(View *owner, Widget *parent)
         : q(owner)
         , mWidget(parent)
         , mDelegate(new Delegate(owner))
@@ -60,7 +59,7 @@ public:
     void gestureEvent(QGestureEvent *e);
     void tapTriggered(QTapGesture *tap);
     void tapAndHoldTriggered(QTapAndHoldGesture *tap);
-    void twoFingerTapTriggered(TwoFingerTap *tap);
+    void twoFingerTapTriggered(KTwoFingerTap *tap);
 
     QColor mTextColor;
     View *const q;
@@ -90,7 +89,7 @@ public:
 
 View::View(Widget *pParent)
     : QTreeView(pParent)
-    , d(new Private(this, pParent))
+    , d(new ViewPrivate(this, pParent))
 {
     d->mSaveThemeColumnStateTimer = new QTimer();
     connect(d->mSaveThemeColumnStateTimer, &QTimer::timeout, this, &View::saveThemeColumnState);
@@ -108,12 +107,12 @@ View::View(Widget *pParent)
 
     d->mScroller = QScroller::scroller(viewport());
     QScrollerProperties scrollerProp;
-    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2);  //QTBUG-88249
+    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); // QTBUG-88249
     d->mScroller->setScrollerProperties(scrollerProp);
     d->mScroller->grabGesture(viewport());
 
     setAttribute(Qt::WA_AcceptTouchEvents);
-    d->mTwoFingerTap = QGestureRecognizer::registerRecognizer(new TwoFingerTapRecognizer());
+    d->mTwoFingerTap = QGestureRecognizer::registerRecognizer(new KTwoFingerTapRecognizer());
     viewport()->grabGesture(d->mTwoFingerTap);
     viewport()->grabGesture(Qt::TapGesture);
     viewport()->grabGesture(Qt::TapAndHoldGesture);
@@ -158,8 +157,6 @@ View::~View()
 
     d->mTheme = nullptr;
     d->mAggregation = nullptr;
-
-    delete d;
 }
 
 Model *View::model() const
@@ -986,7 +983,7 @@ void View::setChildrenExpanded(const Item *root, bool expand)
     }
 }
 
-void View::Private::generalPaletteChanged()
+void View::ViewPrivate::generalPaletteChanged()
 {
     const QPalette palette = q->viewport()->palette();
     QColor color = palette.text().color();
@@ -994,7 +991,7 @@ void View::Private::generalPaletteChanged()
     mTextColor = color;
 }
 
-void View::Private::expandFullThread(const QModelIndex &index)
+void View::ViewPrivate::expandFullThread(const QModelIndex &index)
 {
     if (!index.isValid()) {
         return;
@@ -1182,7 +1179,7 @@ Item *View::messageItemAfter(Item *referenceItem, MessageTypeFilter messageTypeF
     while (
         // is not a message (we want messages, don't we ?)
         (below->type() != Item::Message) || // message filter doesn't match
-        (!message_type_matches(below, messageTypeFilter)) || // is hidden (and we don't want hidden items as they arent "officially" in the view)
+        (!message_type_matches(below, messageTypeFilter)) || // is hidden (and we don't want hidden items as they aren't "officially" in the view)
         isRowHidden(belowIndex.row(), parentIndex) || // is not enabled or not selectable
         ((d->mModel->flags(belowIndex) & (Qt::ItemIsSelectable | Qt::ItemIsEnabled)) != (Qt::ItemIsSelectable | Qt::ItemIsEnabled))) {
         // find the next one
@@ -1363,8 +1360,6 @@ void View::growOrShrinkExistingSelection(const QModelIndex &newSelectedIndex, bo
     int topVisualCoordinate = 0xfffffff; // huuuuuge number
     int bottomVisualCoordinate = -(0xfffffff);
 
-    int candidate;
-
     QModelIndex bottomIndex;
     QModelIndex topIndex;
 
@@ -1388,7 +1383,7 @@ void View::growOrShrinkExistingSelection(const QModelIndex &newSelectedIndex, bo
                 top = bottom;
             }
         }
-        candidate = visualRect(bottom).bottom();
+        int candidate = visualRect(bottom).bottom();
         if (candidate > bottomVisualCoordinate) {
             bottomVisualCoordinate = candidate;
             bottomIndex = range.bottomRight();
@@ -1698,7 +1693,7 @@ void View::markMessageItemsAsAboutToBeRemoved(const QList<MessageItem *> &items,
     // all at once at the latest possible stage.
 
     // A radical approach is needed: we FIRST deal with the selection
-    // by tring to move it away from the messages about to be deleted
+    // by trying to move it away from the messages about to be deleted
     // and THEN mark the (hopefully no longer selected) messages as "about to be deleted".
 
     // First of all, find out if we're going to clear the entire selection (very likely).
@@ -2357,7 +2352,8 @@ bool View::event(QEvent *e)
                     break;
                 }
             } else {
-                if (ghi->label().contains(QRegularExpression(QStringLiteral("[0-9]")))) {
+                static const QRegularExpression reg(QStringLiteral("[0-9]"));
+                if (ghi->label().contains(reg)) {
                     if (storageModel()->containsOutboundMessages()) {
                         description = i18nc("@info:tooltip Formats to something like 'Messages sent on 2008-12-21'", "Messages sent on %1", ghi->label());
                     } else {
@@ -2476,9 +2472,7 @@ bool View::event(QEvent *e)
                        "<nobr>%2</nobr>"
                        "</td>"
                        "</tr>")
-                       .arg(darkerColorName)
-                       .arg(statsText)
-                       .arg(textDirection);
+                       .arg(darkerColorName, statsText, textDirection);
         }
 
         break;
@@ -2495,6 +2489,16 @@ bool View::event(QEvent *e)
     return true;
 }
 
+void View::slotExpandAllThreads()
+{
+    setAllThreadsExpanded(true);
+}
+
+void View::slotCollapseAllThreads()
+{
+    setAllThreadsExpanded(false);
+}
+
 void View::slotCollapseAllGroups()
 {
     setAllGroupsExpanded(false);
@@ -2588,7 +2592,7 @@ void View::setQuickSearchClickMessage(const QString &msg)
     d->mWidget->quickSearch()->setPlaceholderText(msg);
 }
 
-void View::Private::onPressed(QMouseEvent* e)
+void View::ViewPrivate::onPressed(QMouseEvent *e)
 {
     mMousePressPosition = QPoint();
 
@@ -2627,14 +2631,14 @@ void View::Private::onPressed(QMouseEvent* e)
                     break;
                 case Theme::ContentItem::ActionItemStateIcon:
                     q->changeMessageStatus(static_cast<MessageItem *>(it),
-                                        it->status().isToAct() ? Akonadi::MessageStatus() : Akonadi::MessageStatus::statusToAct(),
-                                        it->status().isToAct() ? Akonadi::MessageStatus::statusToAct() : Akonadi::MessageStatus());
+                                           it->status().isToAct() ? Akonadi::MessageStatus() : Akonadi::MessageStatus::statusToAct(),
+                                           it->status().isToAct() ? Akonadi::MessageStatus::statusToAct() : Akonadi::MessageStatus());
                     return; // don't select the item
                     break;
                 case Theme::ContentItem::ImportantStateIcon:
                     q->changeMessageStatus(static_cast<MessageItem *>(it),
-                                        it->status().isImportant() ? Akonadi::MessageStatus() : Akonadi::MessageStatus::statusImportant(),
-                                        it->status().isImportant() ? Akonadi::MessageStatus::statusImportant() : Akonadi::MessageStatus());
+                                           it->status().isImportant() ? Akonadi::MessageStatus() : Akonadi::MessageStatus::statusImportant(),
+                                           it->status().isImportant() ? Akonadi::MessageStatus::statusImportant() : Akonadi::MessageStatus());
                     return; // don't select the item
                 case Theme::ContentItem::ReadStateIcon:
                     q->changeMessageStatusRead(static_cast<MessageItem *>(it), it->status().isRead() ? false : true);
@@ -2642,21 +2646,21 @@ void View::Private::onPressed(QMouseEvent* e)
                     break;
                 case Theme::ContentItem::SpamHamStateIcon:
                     q->changeMessageStatus(static_cast<MessageItem *>(it),
-                                        it->status().isSpam()
-                                            ? Akonadi::MessageStatus()
-                                            : (it->status().isHam() ? Akonadi::MessageStatus::statusSpam() : Akonadi::MessageStatus::statusHam()),
-                                        it->status().isSpam() ? Akonadi::MessageStatus::statusSpam()
-                                                              : (it->status().isHam() ? Akonadi::MessageStatus::statusHam() : Akonadi::MessageStatus()));
+                                           it->status().isSpam()
+                                               ? Akonadi::MessageStatus()
+                                               : (it->status().isHam() ? Akonadi::MessageStatus::statusSpam() : Akonadi::MessageStatus::statusHam()),
+                                           it->status().isSpam() ? Akonadi::MessageStatus::statusSpam()
+                                                                 : (it->status().isHam() ? Akonadi::MessageStatus::statusHam() : Akonadi::MessageStatus()));
                     return; // don't select the item
                     break;
                 case Theme::ContentItem::WatchedIgnoredStateIcon:
                     q->changeMessageStatus(static_cast<MessageItem *>(it),
-                                        it->status().isIgnored()
-                                            ? Akonadi::MessageStatus()
-                                            : (it->status().isWatched() ? Akonadi::MessageStatus::statusIgnored() : Akonadi::MessageStatus::statusWatched()),
-                                        it->status().isIgnored()
-                                            ? Akonadi::MessageStatus::statusIgnored()
-                                            : (it->status().isWatched() ? Akonadi::MessageStatus::statusWatched() : Akonadi::MessageStatus()));
+                                           it->status().isIgnored()
+                                               ? Akonadi::MessageStatus()
+                                               : (it->status().isWatched() ? Akonadi::MessageStatus::statusIgnored() : Akonadi::MessageStatus::statusWatched()),
+                                           it->status().isIgnored()
+                                               ? Akonadi::MessageStatus::statusIgnored()
+                                               : (it->status().isWatched() ? Akonadi::MessageStatus::statusWatched() : Akonadi::MessageStatus()));
                     return; // don't select the item
                     break;
                 default:
@@ -2721,7 +2725,7 @@ void View::Private::onPressed(QMouseEvent* e)
     }
 }
 
-void View::Private::gestureEvent(QGestureEvent *e)
+void View::ViewPrivate::gestureEvent(QGestureEvent *e)
 {
     if (QGesture *gesture = e->gesture(Qt::TapGesture)) {
         tapTriggered(static_cast<QTapGesture *>(gesture));
@@ -2730,11 +2734,11 @@ void View::Private::gestureEvent(QGestureEvent *e)
         tapAndHoldTriggered(static_cast<QTapAndHoldGesture *>(gesture));
     }
     if (QGesture *gesture = e->gesture(mTwoFingerTap)) {
-        twoFingerTapTriggered(static_cast<TwoFingerTap *>(gesture));
+        twoFingerTapTriggered(static_cast<KTwoFingerTap *>(gesture));
     }
 }
 
-void View::Private::tapTriggered(QTapGesture *tap)
+void View::ViewPrivate::tapTriggered(QTapGesture *tap)
 {
     static bool scrollerWasScrolling = false;
 
@@ -2763,9 +2767,21 @@ void View::Private::tapTriggered(QTapGesture *tap)
         }
 
         // simulate a mousePressEvent, to allow QTreeView to select the items
-        QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tap->position(),
-                                    mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
-                                    mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton, Qt::NoModifier);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
+                                   tap->position(),
+                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
+                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
+                                   Qt::NoModifier);
+#else
+        QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
+                                   tap->position(),
+                                   q->viewport()->mapToGlobal(tap->position()),
+                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
+                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
+                                   Qt::NoModifier);
+
+#endif
         onPressed(&fakeMousePress);
         mTapAndHoldActive = false;
     }
@@ -2779,10 +2795,9 @@ void View::Private::tapTriggered(QTapGesture *tap)
     }
 }
 
-void View::Private::tapAndHoldTriggered(QTapAndHoldGesture *tap)
+void View::ViewPrivate::tapAndHoldTriggered(QTapAndHoldGesture *tap)
 {
     if (tap->state() == Qt::GestureFinished) {
-
         // with touch you can touch multiple widgets at the same time, but only one widget will get a mousePressEvent.
         // we use this to select the right window
         if (!mMousePressed) {
@@ -2804,7 +2819,11 @@ void View::Private::tapAndHoldTriggered(QTapAndHoldGesture *tap)
 
         // simulate a mousePressEvent, to allow QTreeView to select the items
         const QPoint tapViewportPos(q->viewport()->mapFromGlobal(tap->position().toPoint()));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+#else
+        QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, tapViewportPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+#endif
         onPressed(&fakeMousePress);
 
         const QPoint tapIndicatorSize(80, 80); // size for the tapAndHold indicator
@@ -2815,10 +2834,9 @@ void View::Private::tapAndHoldTriggered(QTapAndHoldGesture *tap)
     }
 }
 
-void View::Private::twoFingerTapTriggered(TwoFingerTap *tap)
+void View::ViewPrivate::twoFingerTapTriggered(KTwoFingerTap *tap)
 {
     if (tap->state() == Qt::GestureFinished) {
-
         if (mTapAndHoldActive) {
             return;
         }
@@ -2830,7 +2848,16 @@ void View::Private::twoFingerTapTriggered(TwoFingerTap *tap)
         }
 
         // simulate a mousePressEvent with Qt::ControlModifier, to allow QTreeView to select the items
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tap->pos(), Qt::LeftButton, Qt::LeftButton, Qt::ControlModifier);
+#else
+        QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
+                                   tap->pos(),
+                                   q->viewport()->mapToGlobal(tap->pos()),
+                                   Qt::LeftButton,
+                                   Qt::LeftButton,
+                                   Qt::ControlModifier);
+#endif
         onPressed(&fakeMousePress);
     }
 }
