@@ -51,7 +51,7 @@ public:
 
 private:
     Q_REQUIRED_RESULT static int findHeaderLineEnd(const QByteArray &src, int &dataBegin, bool *folded);
-    Q_REQUIRED_RESULT MessageViewer::DKIMHeaderParser::Header extractHeader(const QByteArray &head, const int headerStart, int &endOfFieldBody);
+    Q_REQUIRED_RESULT MESSAGEVIEWER_NO_EXPORT MessageViewer::DKIMHeaderParser::Header extractHeader(const QByteArray &head, const int headerStart, int &endOfFieldBody);
     Q_REQUIRED_RESULT static QByteArray unfoldHeader(const char *header, size_t headerSize);
     QByteArray mHead;
     QVector<DKIMHeaderParser::Header> mListHeaders;
