@@ -1,30 +1,17 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMKEYRECORD_H
-#define DKIMKEYRECORD_H
+#pragma once
 
 #include "messageviewer_export.h"
+#include <QObject>
 #include <QString>
 #include <QStringList>
-#include <QObject>
-namespace MessageViewer {
+namespace MessageViewer
+{
 /**
  * @brief The DKIMKeyRecord class
  * @author Laurent Montel <montel@kde.org>
@@ -57,6 +44,7 @@ public:
     void setFlags(const QStringList &flags);
 
     Q_REQUIRED_RESULT bool operator==(const DKIMKeyRecord &other) const;
+
 private:
     QString mVersion;
     QString mKeyType;
@@ -68,6 +56,4 @@ private:
 };
 }
 Q_DECLARE_METATYPE(MessageViewer::DKIMKeyRecord)
-MESSAGEVIEWER_EXPORT QDebug operator <<(QDebug d, const MessageViewer::DKIMKeyRecord &t);
-
-#endif // DKIMKEYRECORD_H
+MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMKeyRecord &t);
