@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #include "messageviewercheckbeforedeletinginterface.h"
 #include "messageviewercheckbeforedeletingparameters.h"
 
+#include <QAction>
+
 using namespace MessageViewer;
 
 class MessageViewer::MessageViewerCheckBeforeDeletingInterfacePrivate
 {
 public:
-    MessageViewerCheckBeforeDeletingInterfacePrivate()
-    {
-    }
+    MessageViewerCheckBeforeDeletingInterfacePrivate() = default;
 
     MessageViewer::MessageViewerCheckBeforeDeletingParameters parameters;
     QWidget *mParentWidget = nullptr;
@@ -26,10 +26,7 @@ MessageViewerCheckBeforeDeletingInterface::MessageViewerCheckBeforeDeletingInter
 {
 }
 
-MessageViewerCheckBeforeDeletingInterface::~MessageViewerCheckBeforeDeletingInterface()
-{
-    delete d;
-}
+MessageViewerCheckBeforeDeletingInterface::~MessageViewerCheckBeforeDeletingInterface() = default;
 
 void MessageViewerCheckBeforeDeletingInterface::setParentWidget(QWidget *parent)
 {
@@ -55,3 +52,14 @@ MessageViewer::MessageViewerCheckBeforeDeletingParameters MessageViewerCheckBefo
 {
     return d->parameters;
 }
+
+QList<QAction *> MessageViewerCheckBeforeDeletingInterface::actions() const
+{
+    // Reimplement in subclass
+    return {};
+}
+
+void MessageViewerCheckBeforeDeletingInterface::createActions(KActionCollection *ac)
+{
+    Q_UNUSED(ac);
+}
