@@ -1,47 +1,18 @@
-/*******************************************************************************
-**
-** Filename   : util
-** Created on : 03 April, 2005
-** SPDX-FileCopyrightText : 2005 Till Adam <adam@kde.org>
-**
-*******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2005 Till Adam <adam@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+ */
 
-/*******************************************************************************
-**
-**   This program is free software; you can redistribute it and/or modify
-**   it under the terms of the GNU General Public License as published by
-**   the Free Software Foundation; either version 2 of the License, or
-**   (at your option) any later version.
-**
-**   It is distributed in the hope that it will be useful, but
-**   WITHOUT ANY WARRANTY; without even the implied warranty of
-**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-**   General Public License for more details.
-**
-**   You should have received a copy of the GNU General Public License
-**   along with this program; if not, write to the Free Software
-**   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-**
-**   In addition, as a special exception, the copyright holders give
-**   permission to link the code of this program with any edition of
-**   the Qt library by Trolltech AS, Norway (or with modified versions
-**   of Qt that use the same license as Qt), and distribute linked
-**   combinations including the two.  You must obey the GNU General
-**   Public License in all respects for all of the code used other than
-**   Qt.  If you modify this file, you may extend this exception to
-**   your version of the file, but you are not obligated to do so.  If
-**   you do not wish to do so, delete this exception statement from
-**   your version.
-**
-*******************************************************************************/
-#ifndef MESSAGEVIEWERUTIL_H
-#define MESSAGEVIEWERUTIL_H
+#pragma once
 
 #include "messageviewer_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <KMime/Content>
 #include <KService>
-
+#include <QTextCodec>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QStringConverter>
+#endif
 class QUrl;
 class QWidget;
 class QActionGroup;
@@ -74,7 +45,9 @@ Q_REQUIRED_RESULT MESSAGEVIEWER_EXPORT QAction *createAppAction(const KService::
 /** Return a QTextCodec for the specified charset.
  * This function is a bit more tolerant, than QTextCodec::codecForName */
 MESSAGEVIEWER_EXPORT const QTextCodec *codecForName(const QByteArray &_str);
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+MESSAGEVIEWER_EXPORT QStringConverter::Encoding htmlEncoding(const QByteArray &data, const QByteArray &codec);
+#endif
 struct HtmlMessageInfo {
     QString htmlSource;
     QString extraHead;
@@ -95,4 +68,3 @@ Q_DECLARE_TYPEINFO(MessageViewer::Util::HtmlMessageInfo, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(MessageViewer::Util::HtmlMessageInfo)
 MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::Util::HtmlMessageInfo &t);
 Q_DECLARE_METATYPE(KService::Ptr)
-#endif
