@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -21,9 +21,7 @@ TemplateParserEmailRequesterTestWidget::TemplateParserEmailRequesterTestWidget(Q
     lay->addWidget(w);
 }
 
-TemplateParserEmailRequesterTestWidget::~TemplateParserEmailRequesterTestWidget()
-{
-}
+TemplateParserEmailRequesterTestWidget::~TemplateParserEmailRequesterTestWidget() = default;
 
 int main(int argc, char **argv)
 {
